@@ -4,7 +4,7 @@ import time
 from os import environ
 from typing import Optional, Sequence, Dict, Union, cast, Iterator, Iterable, List
 from datetime import timedelta
-from api_session import APISession
+from api_session import APISession, JSONDict
 import requests
 from requests.exceptions import HTTPError
 
@@ -93,7 +93,7 @@ class Magento(APISession):
                  token: Optional[str] = None,
                  base_url: Optional[str] = None,
                  scope: Optional[str] = None,
-                 logger: Logger = None,
+                 logger: Optional[Logger] = None,
                  read_only=False,
                  user_agent=None,
                  verbose=False,
@@ -401,6 +401,13 @@ class Magento(APISession):
 
         return self.save_order(payload)
 
+    # Credit Memos
+    # ============
+
+    def get_credit_memos(self, query: Query = None, limit=-1) -> Iterable[MagentoEntity]:
+        """Get all credit memos (generator)."""
+        return self.get_paginated("/V1/creditmemos", query=query, limit=limit)
+
     # Prices
     # ======
 
@@ -539,33 +546,47 @@ class Magento(APISession):
     def delete_product_media(self, sku: Sku, media_id: PathId, throw=False):
         return self.delete_api(f'/V1/products/{sku}/media/{media_id}', throw=throw)
 
-    def save_product(self, product, log_response=False) -> Product:
+    def save_product(self, product, *, log_response=False, save_options: Optional[bool] = None) -> Product:
         """
         Save a product.
 
         :param product: (partial) product to save.
         :param log_response: if True and ``self.logger`` is set, log the response.
+        :param save_options: set the `saveOptions` attribute.
         :return:
         """
+        payload: JSONDict = {"product": product}
+        if save_options is not None:
+            payload["saveOptions"] = save_options
+
         # throw=False so the log is printed before we raise
-        resp = self.post_api('/V1/products', json={"product": product}, throw=False)
+        resp = self.post_api('/V1/products', json=payload, throw=False)
         if log_response and self.logger:
             self.logger.info("Save product response: %s", resp.text)
         raise_for_response(resp)
         return cast(Product, resp.json())
 
-    def update_product(self, sku: Sku, product_data: Product) -> Product:
+    def update_product(self, sku: Sku, product: Product, *, save_options: Optional[bool] = None) -> Product:
         """
         Update a product.
 
         Example:
             >>> Magento().update_product("SK1234", {"name": "My New Name"})
 
+        To update the SKU of a product, pass its id along the new SKU and set `save_options=True`:
+
+            >>> Magento().update_product("old-sku", {"id": 123, "sku": "new-sku"}, save_options=True)
+
         :param sku: SKU of the product to update
-        :param product_data: (partial) product data to update
+        :param product: (partial) product data to update
+        :param save_options: set the `saveOptions` attribute.
         :return: updated product
         """
-        return cast(Product, self.put_api(f'/V1/products/{sku}', json={"product": product_data}, throw=True).json())
+        payload: JSONDict = {"product": product}
+        if save_options is not None:
+            payload["saveOptions"] = save_options
+
+        return cast(Product, self.put_api(f'/V1/products/{sku}', json=payload, throw=True).json())
 
     def delete_product(self, sku: Sku, skip_missing=False, throw=True, **kwargs) -> bool:
         """
@@ -702,6 +723,15 @@ class Magento(APISession):
         response = self.delete_api(f'/V1/products/attributes/{attribute_code}/options/{option_id}', throw=True)
         return cast(bool, response.json())
 
+    # Aliases
+    # -------
+
+    def get_manufacturers(self):
+        """
+        Shortcut for `.get_products_attribute_options("manufacturer")`.
+        """
+        return self.get_products_attribute_options("manufacturer")
+
     # Sales Rules
     # ===========
 
@@ -736,22 +766,27 @@ class Magento(APISession):
     # ============
 
     def get_source_items(self, source_code: Optional[str] = None, sku: Optional[str] = None,
-                         *, query: Query = None, limit=-1) -> Iterable[MagentoEntity]:
+                         *,
+                         skus: Optional[Iterable[str]] = None,
+                         query: Query = None, limit=-1) -> Iterable[MagentoEntity]:
         """
         Return a generator of all source items.
 
         :param source_code: optional source_code to filter on. This takes precedence over the query parameter.
-        :param sku: option SKU to filter on. This takes precedence over the query parameter.
+        :param sku: optional SKU to filter on. This takes precedence over the query and the skus parameter.
+        :param skus: optional SKUs list to filter on. This takes precedence of the query parameter.
         :param query: optional query.
         :param limit: -1 for unlimited.
         :return:
         """
-        if source_code or sku:
+        if source_code or sku or skus:
             filter_groups = []
             if source_code:
                 filter_groups.append([("source_code", source_code, "eq")])
             if sku:
                 filter_groups.append([("sku", sku, "eq")])
+            elif skus:
+                filter_groups.append([("sku", ",".join(skus), "in")])
 
             query = make_search_query(filter_groups)
 
@@ -811,6 +846,13 @@ class Magento(APISession):
         """Get all tax rules (generator)."""
         return self.get_paginated("/V1/taxRules/search", query=query, limit=limit)
 
+    # Modules
+    # =======
+
+    def get_modules(self, query: Query = None, limit=-1) -> Iterable[MagentoEntity]:
+        """Get all enabled modules (generator)."""
+        return self.get_paginated("/V1/modules", query=query, limit=limit)
+
     # Internals
     # =========
 
